r57514 - in /trunk/libxml-xql-perl: lib/XML/XQL.pm t/xql_sin2.t

gregoa at users.alioth.debian.org gregoa at users.alioth.debian.org
Wed May 5 15:10:45 UTC 2010


Author: gregoa
Date: Wed May  5 15:10:38 2010
New Revision: 57514

URL: http://svn.debian.org/wsvn/pkg-perl/?sc=1&rev=57514
Log:
un-apply patches

Modified:
    trunk/libxml-xql-perl/lib/XML/XQL.pm
    trunk/libxml-xql-perl/t/xql_sin2.t

Modified: trunk/libxml-xql-perl/lib/XML/XQL.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/lib/XML/XQL.pm?rev=57514&op=diff
==============================================================================
--- trunk/libxml-xql-perl/t/xql_sin2.t (original)
+++ trunk/libxml-xql-perl/t/xql_sin2.t Wed May  5 15:10:38 2010
@@ -22,7 +22,7 @@
     $^W=0;
     my $data = join('',<DATA>);
 #print "{{$data}}\n{{$str}}\n";
-    assert_ok ($str =~ /^$data$/s);
+    assert_ok ($str eq $data);
 }
 #Test 2
 
@@ -49,15 +49,15 @@
 __DATA__
 <array>
   <item index='0'>
-    <obj type='XML::XQL::Number'>0\.841470984807[0-9]+</obj>
+    <obj type='XML::XQL::Number'>0.841470984807897</obj>
   </item>
   <item index='1'>
-    <obj type='XML::XQL::Number'>0\.909297426825[0-9]+</obj>
+    <obj type='XML::XQL::Number'>0.909297426825682</obj>
   </item>
   <item index='2'>
-    <obj type='XML::XQL::Number'>0\.141120008059[0-9]+</obj>
+    <obj type='XML::XQL::Number'>0.141120008059867</obj>
   </item>
   <item index='3'>
-    <obj type='XML::XQL::Number'>-0\.756802495307[0-9]+</obj>
+    <obj type='XML::XQL::Number'>-0.756802495307928</obj>
   </item>
 </array>




More information about the Pkg-perl-cvs-commits mailing list
--- trunk/libxml-xql-perl/lib/XML/XQL.pm (original)
+++ trunk/libxml-xql-perl/lib/XML/XQL.pm Wed May  5 15:10:38 2010
@@ -3161,7 +3161,7 @@
 # Text, CDATASection:
 # - xql_data: return expanded text value
 #
 # -xql_element could be overridden to speed up performance
 #
 
 1;
@@ -3363,8 +3363,8 @@
 		new XML::XQL::Date ($elem->xql_text, $elem); 
 	});
 
-These converters can only be specified at a global level, not on a per query
-basis. To undefine a converter, simply pass a FUNCREF of undef.
+These convertors can only be specified at a global level, not on a per query
+basis. To undefine a convertor, simply pass a FUNCREF of undef.
 
 =item defineAttrValueConvertor (ELEM_TAG_NAME, ATTR_NAME, FUNCREF)
 
@@ -3378,8 +3378,8 @@
 FUNCREF should be a reference to a Perl function, e.g. \&my_sub, or
 an anonymous sub.
 
-These converters can only be specified at a global level, not on a per query
-basis. To undefine a converter, simply pass a FUNCREF of undef.
+These convertors can only be specified at a global level, not on a per query
+basis. To undefine a convertor, simply pass a FUNCREF of undef.
 
 =item defineTokenQ (Q)
 
@@ -3830,7 +3830,7 @@
 The resulting values are then casted to the type of the object with the highest
 xql_primType() value. They are as follows: Node (0), Text (1), Number (2),
 Boolean (3), Date (4), other data types (4 by default, but this may be
-overridden by the user.)
+overriden by the user.)
 
 E.g. if one value is a Text value and the other is a Number, the Text value is 
 cast to a Number and the resulting low-level (Perl) comparison is (for $eq$):
@@ -3161,7 +3161,7 @@
 # - xql_data: return expanded text value
 #
-# -xql_element could be overridden to speed up performance
+# -xql_element could be overriden to speed up performance
 #
 

Modified: trunk/libxml-xql-perl/t/xql_sin2.t
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libxml-xql-perl/t/xql_sin2.t?rev=57514&op=diff
==============================================================================